summaryrefslogtreecommitdiff
path: root/include/fb_mmc.h
diff options
context:
space:
mode:
authorSimon Glass <sjg@chromium.org>2020-05-10 20:39:57 +0300
committerTom Rini <trini@konsulko.com>2020-05-19 00:33:33 +0300
commit0528979fa7ab7853faaf2ecf34b7721dd4c0b383 (patch)
tree2c2de398634b542e2457b2c3f857bd7006779d14 /include/fb_mmc.h
parent90526e9fbac47af16d70f323feae45d8d1b0f9b7 (diff)
downloadu-boot-0528979fa7ab7853faaf2ecf34b7721dd4c0b383.tar.xz
part: Drop disk_partition_t typedef
We should not be using typedefs and these make it harder to use forward declarations (to reduce header file inclusions). Drop the typedef. Signed-off-by: Simon Glass <sjg@chromium.org>
Diffstat (limited to 'include/fb_mmc.h')
-rw-r--r--include/fb_mmc.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/fb_mmc.h b/include/fb_mmc.h
index 95db001bee..0c58109e2f 100644
--- a/include/fb_mmc.h
+++ b/include/fb_mmc.h
@@ -11,12 +11,13 @@
*
* @part_name: Named partition to lookup
* @dev_desc: Pointer to returned blk_desc pointer
* @part_info: Pointer to returned disk_partition_t
* @response: Pointer to fastboot response buffer
*/
int fastboot_mmc_get_part_info(const char *part_name,
struct blk_desc **dev_desc,
- disk_partition_t *part_info, char *response);
+ struct disk_partition *part_info,
+ char *response);
/**
* fastboot_mmc_flash_write() - Write image to eMMC for fastboot
@@ -11,12 +11,13 @@
* @part_name: Named partition to lookup
* @dev_desc: Pointer to returned blk_desc pointer
- * @part_info: Pointer to returned disk_partition_t
+ * @part_info: Pointer to returned struct disk_partition
* @response: Pointer to fastboot response buffer
*/